# Changelog

## 0.6.0 (2026-02-10)

Full Changelog: [v0.5.1...v0.6.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.5.1...v0.6.0)

### Features

* **api:** manual updates ([a245c4a](https://github.com/kater-ai/kater-python-sdk/commit/a245c4af66be42f56225fa7fbb0e419efaa35320))
* **api:** manual updates ([d2e3e1d](https://github.com/kater-ai/kater-python-sdk/commit/d2e3e1d7b3be8b59fd6921283d6c3b7083014a4d))
* **api:** manual updates ([7c32ece](https://github.com/kater-ai/kater-python-sdk/commit/7c32eced7c16df58a225951404973f1b3cf48ed8))
* **api:** manual updates ([985f3cb](https://github.com/kater-ai/kater-python-sdk/commit/985f3cb5388d8e181e6a8686bdba439e3985d5d3))
* **api:** manual updates ([c8a945c](https://github.com/kater-ai/kater-python-sdk/commit/c8a945cdea037b68b13025929668b2d1f9ee4ca5))


### Bug Fixes

* **api:** prune orphaned schemas and preserve auto-generated security… ([a6af3dd](https://github.com/kater-ai/kater-python-sdk/commit/a6af3dda2068cfb67bd63f857ee8eb2ee49d0c9d))


### Chores

* add internal route tagging, clean up CLI, and fix CI build issues ([3313bdc](https://github.com/kater-ai/kater-python-sdk/commit/3313bdc24743c68e0415fcf5fb12cf014c4234be))

## 0.5.1 (2026-02-09)

Full Changelog: [v0.5.0...v0.5.1](https://github.com/kater-ai/kater-python-sdk/compare/v0.5.0...v0.5.1)

## 0.5.0 (2026-02-08)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.4.0...v0.5.0)

### Features

* added patch connection and credentials ([fdd46a3](https://github.com/kater-ai/kater-python-sdk/commit/fdd46a31386b0f73c4547191cd5eac93d246e34b))
* **api,core:** simplify connection creation and fix migration chain ([596e9d7](https://github.com/kater-ai/kater-python-sdk/commit/596e9d76b99aacc380a0e1836331a9973257ff86))
* Chore/cleanup connection models ([ad51c89](https://github.com/kater-ai/kater-python-sdk/commit/ad51c89f39a99e823020679ca5e8e0d8a97be3d3))
* **client:** add custom JSON encoder for extended type support ([2af9fb8](https://github.com/kater-ai/kater-python-sdk/commit/2af9fb811c6c09d41d75d8d870cddb13f85b3bc6))
* **core,api,web:** display real synced view files in schema sync UI ([e3421e9](https://github.com/kater-ai/kater-python-sdk/commit/e3421e97585f2bc6179caa7f9de8ae43712f50bb))
* **core,api,web:** implement async schema sync with Hatchet workflow… ([70ab7f2](https://github.com/kater-ai/kater-python-sdk/commit/70ab7f23dfb2f61bb1d39487860d303af134112e))
* **core,api:** add database_object_name field to Database and Schema ([2700d6c](https://github.com/kater-ai/kater-python-sdk/commit/2700d6c33e298112baa60913a271dc3b26f44b0a))
* **core,api:** add PR approval flow for connection creation ([22d94ac](https://github.com/kater-ai/kater-python-sdk/commit/22d94aca4238dccecec59377d92a653202ccd292))
* Feat/fix create connection fe ([79797f4](https://github.com/kater-ai/kater-python-sdk/commit/79797f4ac92048ea7b5a8d896626cd7d7bbca2dd))
* **tenants:** serve tenant and group YAML from server-side schema en… ([4918cbe](https://github.com/kater-ai/kater-python-sdk/commit/4918cbec00c6e383b9e1225fac6d971e5a184bf9))


### Chores

* **ci:** add missing environment ([83bbb43](https://github.com/kater-ai/kater-python-sdk/commit/83bbb4373a2c2813719d1760249ece795190b571))

## 0.4.0 (2026-01-29)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** improve OpenAPI spec generation with pre-commit validation ([bd7fb83](https://github.com/kater-ai/kater-python-sdk/commit/bd7fb83370d26957f2ace147d8544b6f78df4160))

## 0.3.0 (2026-01-28)

Full Changelog: [v0.2.1...v0.3.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.2.1...v0.3.0)

### Features

* **api:** manual updates ([0a76475](https://github.com/kater-ai/kater-python-sdk/commit/0a7647569f34ae69b94fed8fc624a2f48e34a049))

## 0.2.1 (2026-01-27)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/kater-ai/kater-python-sdk/compare/v0.2.0...v0.2.1)

## 0.2.0 (2026-01-26)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** switch to oidc based auth ([5de423f](https://github.com/kater-ai/kater-python-sdk/commit/5de423f3de317ffa738613fd438da89df0494110))
* **api:** update stainless config ([095300b](https://github.com/kater-ai/kater-python-sdk/commit/095300b675e3e21df0aa6a0bb8cbec3d368202dd))

## 0.1.0 (2026-01-26)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/kater-ai/kater-python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** update auth params ([e9f46b6](https://github.com/kater-ai/kater-python-sdk/commit/e9f46b611564f4f604de6ded57d5f60a94033ab0))


### Chores

* update SDK settings ([dc43ba4](https://github.com/kater-ai/kater-python-sdk/commit/dc43ba4053472a0962b443bdbc67b16e05ede62b))
* update SDK settings ([333f170](https://github.com/kater-ai/kater-python-sdk/commit/333f170ceaac38dccd8112fcb99915667ad98330))
